# -*- coding: utf-8 -*-
"""
app.users.views
~~~~~~~~~~~~~~~

This module implements the users blueprint.

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
from flask import Blueprint, render_template, request, redirect, url_for
from flask_login import login_user, logout_user, login_required, current_user
from flask_ldap3_login.forms import LDAPLoginForm
from flask_jwt_extended import create_access_token

bp = Blueprint('users', __name__)


@bp.route('/login', methods=['GET', 'POST'])
def login():
    form = LDAPLoginForm(request.form)
    if form.validate_on_submit():
        login_user(form.user, remember=form.remember_me.data)
        return redirect(request.args.get('next') or url_for('main.index'))
    return render_template('users/login.html', form=form)


@bp.route('/logout')
@login_required
def logout():
    logout_user()
    return redirect(url_for('users.login'))


@bp.route('/profile')
@login_required
def profile():
    return render_template('users/profile.html', user=current_user, token='')


@bp.route('/token')
@login_required
def get_token():
    token = create_access_token(identity=current_user.id)
    return render_template('users/profile.html', user=current_user, token=token)
